# Generated by Django 3.0.13 on 2021-03-20 18:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('watermarker', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='watermark',
            name='image',
            field=models.ImageField(upload_to='watermarks', verbose_name='image'),
        ),
        migrations.AlterField(
            model_name='watermark',
            name='is_active',
            field=models.BooleanField(blank=True, default=True, verbose_name='is active'),
        ),
    ]



# -*- coding: utf-8 -*-

import warnings

from django.conf import settings  # pylint: disable=W0611

from appconf import AppConf


class WatermarkSettings(AppConf):
    QUALITY = 85
    OBSCURE_ORIGINAL = True
    RANDOM_POSITION_ONCE = True
    WATERMARK_PERCENTAGE = 30

    class Meta:
        prefix = 'watermark'
        holder = 'watermarker.conf.settings'

    def configure_quality(self, value):
        if getattr(settings, 'WATERMARKING_QUALITY', None):
            warnings.warn("WATERMARKING_QUALITY is deprecated, use WATERMARK_QUALITY", DeprecationWarning)

        return value



import os
from setuptools import setup, find_packages

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

from watermarker import __version__

setup(
    name='django-watermark',
    version=__version__,
    packages=find_packages(exclude=['example']),
    include_package_data=True,
    license='BSD License',
    description="Quick and efficient way to apply watermarks to images in Django.",
    long_description=README,
    keywords='django, watermark, image, photo, logo',
    url='http://github.com/bashu/django-watermark/',
    author='Josh VanderLinden',
    author_email='codekoala@gmail.com',
    maintainer='Basil Shubin',
    maintainer_email='basil.shubin@gmail.com',
    install_requires=[
        'django>=1.4',
        'django-appconf',
        'pillow',
        'six',
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Artistic Software',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Multimedia :: Graphics'
    ],
    zip_safe=False
)
